I18Next class

Constructors

I18Next(Locale _locale, TranslationLoader? translationLoader, {InterpolationOptions? interpolationOptions})

Properties

decodedMap ↔ Map?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isLoadedStream → Stream<bool>
no setter
loadingStream → Stream<LoadingStatus>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → dynamic
load() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

retrieveLoadedStream(BuildContext context) → Stream<bool>
Used to check if the translation file is still loading
retrieveLoadingStream(BuildContext context) → Stream<LoadingStatus>
Used to retrieve the loading status stream
t(BuildContext context, String key, {List<String>? fallbackKeys, String? defaultValue, Map<String, dynamic>? params, int? count}) → String