LocalTranslationLoader class

Inheritance

Constructors

LocalTranslationLoader({dynamic basePath = "assets/i18next", dynamic useCountryCode = false, dynamic decodeStrategies})

Properties

assetBundle → AssetBundle
finalinherited
basePath → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useCountryCode → bool
finalinherited

Methods

composeCountryCode(Locale locale) → String
Return the country code to attach to the file name, if required
inherited
composeFileName(Locale locale) → String
Compose the file name using the format languageCode_countryCode
inherited
load(Locale locale) → Future<Map?>
Return the translation Map
inherited
loadFile(String fileName) → Future<Map?>
Load the fileName using one of the strategies provided
inherited
loadString(String fileName, String extension) → Future<String>
Load the file using the File class
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited