InterpolationOptions class

Constructors

InterpolationOptions({FormatCallback? formatter, String formatSeparator = ','})

Properties

formatSeparator → String
final
formatter → FormatCallback?
final
hashCode → int
The hash code for this object.
no setterinherited
pattern → RegExp
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited