Translator class

Constructors

Translator(Map? map, String key, {required Locale locale, int? count, InterpolationOptions? interpolation, List<String>? fallbackKeys, String? defaultValue, Map<String, dynamic>? params})

Properties

count → int?
final
hashCode → int
The hash code for this object.
no setterinherited
locale → Locale
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
translate() → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited